Work orders report

WO # | Equipment (Description) | Client | Open date | Finish date | Total
00666 | Description - Work order 0 | Client 0 | 08/04/07 |  | $ 0.00
00667 | Description - Work order 1 | Client 1 | 08/04/07 |  | $10.00
00668 | Description - Work order 2 | Client 2 | 08/04/07 |  | $20.00
00669 | Description - Work order 3 | Client 3 | 08/04/07 |  | $30.00
00670 | Description - Work order 4 | Client 4 | 08/04/07 |  | $40.00
|  |  |  |  | $100.00